==> ksnuffle-0.1.tgz: ksnuffle-0.1/ksnuffle/resource.h <==
/***************************************************************************
                          resource.h  -  description                              
                             -------------------                                         
    begin                : Thu Mar 25 14:26:46 GMT 1999
                                           
    copyright            : (C) 1999 by Mike Richardson                         
    email                : mike@quaking.demon.co.uk                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef RESSOURCE_H
#define RESSOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


///////////////////////////////////////////////////////////////////
// Monitor-menu entries
#define ID_MONITOR_NEW              10010
#define ID_MONITOR_CLOSE            10020
#define	ID_MONITOR_START	    10030
#define	ID_MONITOR_STOP		    10040
#define	ID_MONITOR_FREEZE	    10050
#define	ID_MONITOR_RESUME	    10060
#define	ID_MONITOR_SAVE		    10070
#define	ID_MONITOR_SAVE_QUIT	    10080
#define ID_MONITOR_QUIT             10090
#define	ID_MONITOR_REPLAY	    10100

///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_CONFIG		    12030
#define ID_VIEW_GRAPHIC		    12040
#define ID_VIEW_PACKETS		    12050
#define	ID_VIEW_MONITORS	    12060
#define	ID_VIEW_MULTI		    12070
#define	ID_VIEW_SETUP		    12080
#define	ID_VIEW_SELECT		    12200

#define	ID_MONITOR_LIST		    14010

///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP                     1002

///////////////////////////////////////////////////////////////////
// General application values
#define IDS_APP_ABOUT               "Ksnuffle Version " VERSION "\n"	\
				    "Mike Richardson mike@quaking.demon.co.uk"






///////////////////////////////////////////////////////////////////
// MACROS FOR THE CONNECT OF YOUR SIGNALS TO CORRESPONDENT SLOTS 
// IN YOUR MAIN IMPLEMENTATION OF MENUBAR AND TOOLBAR


///////////////////////////////////////////////////////////////////
// Create cases for entries and connect them with their functions
#define ON_CMD(id, cmd_class_function)   case id:cmd_class_function ;break;

#endif // RESOURCE_H

==> ksnuffle-0.6.tgz: ksnuffle-0.6/ksnuffle/resource.h <==
/***************************************************************************
                          resource.h  -  description                              
                             -------------------                                         
    begin                : Thu Mar 25 14:26:46 GMT 1999
                                           
    copyright            : (C) 1999 by Mike Richardson                         
    email                : mike@quaking.demon.co.uk                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef RESSOURCE_H
#define RESSOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR, TOOLBAR SND STATUSBAR ENTRIES


///////////////////////////////////////////////////////////////////
// Monitor-menu entries
#define ID_MONITOR_NEW              10010
#define ID_MONITOR_CLOSE            10020
#define	ID_MONITOR_START	    10030
#define	ID_MONITOR_STOP		    10040
#define	ID_MONITOR_FREEZE	    10050
#define	ID_MONITOR_RESUME	    10060
#define	ID_MONITOR_SAVE		    10070
#define	ID_MONITOR_SAVE_QUIT	    10080
#define ID_MONITOR_QUIT             10090
#define	ID_MONITOR_REPLAY	    10100
#define	ID_MONITOR_REMOTE	    10110
#define	ID_TCPDATA_REFRESH	    10120
#define	ID_DETAILS_EXPAND	    10130
#define	ID_DETAILS_COLLAPSE	    10140
#define	ID_DETAILS_PREVIOUS	    10150
#define	ID_DETAILS_NEXT		    10160
#define	ID_DETAILS_FIRST	    10170
#define	ID_DETAILS_LAST		    10180

///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020
#define ID_VIEW_CONFIG		    12030
#define	ID_VIEW_TRIGGERS	    12040
#define ID_VIEW_GRAPHIC		    12050
#define ID_VIEW_PACKETS		    12060
#define	ID_VIEW_MONITORS	    12070
#define	ID_VIEW_MULTI		    12080
#define	ID_VIEW_SETUP		    12090
#define	ID_VIEW_EVENTS		    13000
#define	ID_VIEW_USER		    13010

#define	ID_VIEW_SELECT		    12200

#define	ID_MONITOR_LIST		    14010
#define	ID_MONITOR_STATE	    14020
#define	ID_MONITOR_FROZEN	    14030
#define ID_MONITOR_PAUSED	    14040
#define	ID_MONITOR_LOAD1	    14050
#define	ID_MONITOR_LOAD2	    14060

///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP                     1002

///////////////////////////////////////////////////////////////////
// General application values
#define IDS_APP_ABOUT               "Ksnuffle Version " VERSION "\n"	\
				    "Mike Richardson mike@quaking.demon.co.uk"






///////////////////////////////////////////////////////////////////
// MACROS FOR THE CONNECT OF YOUR SIGNALS TO CORRESPONDENT SLOTS 
// IN YOUR MAIN IMPLEMENTATION OF MENUBAR AND TOOLBAR


///////////////////////////////////////////////////////////////////
// Create cases for entries and connect them with their functions
#define ON_CMD(id, cmd_class_function)   case id:cmd_class_function ;break;

#endif // RESOURCE_H
